@@ -15,8 +15,8 @@ except ImportError:
     from hashlib import md5 as xxh
 from sos.utils import env
 from sos.targets import fileMD5, executable
-from .utils import FormatError, strip_dict, find_nested_key, recursive_items, merge_lists, flatten_list, uniq_list, \
-     try_get_value, dict2str, set_nested_value, locate_file, filter_sublist, cartesian_list, \
+from .utils import FormatError, strip_dict, recursive_items, merge_lists, flatten_list, uniq_list, \
+     try_get_value, dict2str, locate_file, filter_sublist, cartesian_list, \
      parens_aware_split, remove_parens, remove_quotes, rmd_to_r, update_gitconf, install_package_interactive, \
      dsc2html
 from .syntax import *
@@ -97,7 +97,6 @@ class DSC_Script:
                 self.content['DSC'] = dict()
         self.get_global_params(global_params)
         global_vars = try_get_value(self.content, ('DSC', 'global'))
-        self.set_global_vars(global_vars)
         self.content = EntryFormatter()(self.content, global_vars)
         derived, sorted_blocks = self.get_derived_blocks()
         for block in sorted_blocks:
@@ -266,15 +265,6 @@ class DSC_Script:
                     f'Parameter ``--{k}`` is ignored because it is not found in ``DSC::global`` section.'
                 )
 
-    def set_global_vars(self, gvars):
-        if gvars is None:
-            return
-        for v in gvars:
-            for block in self.content:
-                keys = list(find_nested_key(v, self.content[block]))
-                for k in keys:
-                    set_nested_value(self.content[block], k, gvars[v])
-
     @staticmethod
     def validate_var_name(val, is_parameter):
         tip = f"If this limitation is irrelevant to your problem, and you really cannot rename variable in your code, then at your own risk you can rename ``{val}`` to, eg, ``name`` in DSC and use ``@ALIAS: {val} = name``."
@@ -676,6 +666,8 @@ class DSC_Module:
         self.exe = None
         # script plugin object
         self.plugin = None
+        # script seed option
+        self.seed = None
         # runtime variables
         self.workdir = None
         self.libpath = None
@@ -933,15 +925,18 @@ class DSC_Module:
         libpath2 = try_get_value(spec_option, 'lib_path')
         path1 = try_get_value(common_option, 'exec_path')
         path2 = try_get_value(spec_option, 'exec_path')
-        container1 = try_get_value(common_option, 'container', [None])[0]
-        container2 = try_get_value(spec_option, 'container', [None])[0]
-        container_engine1 = try_get_value(common_option, 'container_engine', [None])[0]
-        container_engine2 = try_get_value(spec_option, 'container_engine', [None])[0]
+        container1 = try_get_value(common_option, 'container')
+        container2 = try_get_value(spec_option, 'container')
+        container_engine1 = try_get_value(common_option, 'container_engine')
+        container_engine2 = try_get_value(spec_option, 'container_engine')
+        seed1 = try_get_value(common_option, 'seed', 'HASH')
+        seed2 = try_get_value(spec_option, 'seed')
         self.workdir = workdir2 if workdir2 is not None else workdir1
         self.libpath = libpath2 if libpath2 is not None else libpath1
         self.path = path2 if path2 is not None else path1
-        self.container = container2 if container2 is not None else container1
-        self.container_engine = container_engine2 if container_engine2 is not None else container_engine1
+        self.seed = seed2[0] if seed2 is not None else seed1
+        self.container = container2[0] if container2 is not None else container1
+        self.container_engine = container_engine2[0] if container_engine2 is not None else container_engine1
         self.rlib = try_get_value(spec_option, 'R_libs', [])
         self.pymodule = try_get_value(spec_option, 'python_modules', [])
         if not self.container is None and (self.rlib or self.pymodule):
@@ -951,9 +946,9 @@ class DSC_Module:
 
     def set_input(self, params, alias):
         if params is not None:
-            # handle input groups (n,p):(1,2)
             for p in params:
                 if ',' in p:
+                    # handle input groups (n,p):(1,2)
                     ps = parens_aware_split(remove_parens(p))
                     self.pg.append(ps)
                     for pp in ps:
@@ -1072,6 +1067,9 @@ class DSC_Module:
                         if isinstance(self.p[g][j], str) else self.p[g][j])
                     for g in group
                 ]))
+            # https://github.com/stephenslab/dsc/issues/215
+            for g in group:
+                self.p[g] = uniq_list(self.p[g])
         if len(tmp):
             ft.append(' OR '.join([f"({x})" for x in tmp]))
         if len(ft) == 0:
