@@ -41,7 +41,7 @@ class DSC_Translator:
                     for kk in runtime.groups[k]:
                         host_conf[kk] = host_conf[k]
                     del host_conf[k]
-        conf_header = 'from dsc.dsc_database import build_config_db, ResultDB\n'
+        conf_header = 'import os\nfrom dsc.dsc_database import build_config_db, ResultDB\n'
         job_header = f"[global]\nimport os\n\nIO_DB = '{self.output}/{self.db}.conf.mpk'\n\n"\
                      f"{inspect.getsource(load_io_db)}"
         processed_steps = dict()
@@ -154,21 +154,22 @@ class DSC_Translator:
                                    '\n'.join(['\t' + x for x in conf_str_py.split('\n')])) + \
                             "\n[deploy_2 (Configuring output filenames)]\n"\
                             f"parameter: vanilla = {rerun}\n"\
-                            f"input: '{DSC_CACHE}/{self.db}.io.mpk'\n"\
                             f"output: '{self.output}/{self.db}.map.mpk', "\
                             f"'{self.output}/{self.db}.conf.mpk'"\
                             "\nbuild_config_db(str(_input[0]), str(_output[0]), "\
                             f"str(_output[1]), vanilla = vanilla, jobs = {n_cpu})\n"\
+                            f"if os.path.isfile('{self.output}/{self.db}.db'): os.remove('{self.output}/{self.db}.db')\n"\
                             "\n[build (Build meta-database)]\n"\
                             f"depends: '{DSC_CACHE}/{self.db}.io.mpk', '{self.output}/{self.db}.map.mpk'\n"\
                             f"output: '{self.output}/{self.db}.db'"\
                             "\nResultDB(f'{_output:n}')."\
                             f"Build(script = open('{runtime.output}.html').read(), groups = {runtime.groups}, depends = {self.get_dependency()}, pipelines = {runtime.sequence})"
         #
-        self.install_libs(runtime.rlib, "R_library")
-        self.install_libs([x for x in runtime.pymodule if x != 'dsc'],
+        if not debug:
+            self.install_libs(runtime.rlib, "R_library")
+            self.install_libs([x for x in runtime.pymodule if x != 'dsc'],
                           "Python_Module")
-        self.pull_images(runtime.container)
+            self.pull_images(runtime.container)
 
     def get_pipeline(self, task, save=False):
         if task == 'prepare':
@@ -424,13 +425,10 @@ class DSC_Translator:
                 for idx, (plugin, cmd) in enumerate(
                         zip([self.step.plugin], [self.step.exe])):
                     sigil = '$[ ]' if plugin.name == 'bash' else '${ }'
-                    if self.conf is None:
-                        self.action += f'{"python3" if plugin.name == "python" else plugin.name}: expand = "{sigil}"'
-                        if path(self.step.workdir).absolute() != path.cwd():
-                            self.action += f", workdir = {repr(self.step.workdir)}"
-                        self.action += f', stderr = f"{{_output:n}}.stderr", stdout = f"{{_output:n}}.stdout"'
-                    else:
-                        self.action += f'{"python3" if plugin.name == "python" else plugin.name}: expand = "{sigil}"'
+                    self.action += f'{"python3" if plugin.name == "python" else plugin.name}: expand = "{sigil}"'
+                    if path(self.step.workdir).absolute() != path.cwd():
+                        self.action += f", workdir = {repr(self.step.workdir)}"
+                    self.action += f', stderr = f"{{_output:n}}.stderr", stdout = f"{{_output:n}}.stdout"'
                     if self.step.container:
                         self.action += f", container={repr(self.step.container)}"
                         if self.step.container_engine:
@@ -449,7 +447,8 @@ class DSC_Translator:
                                 and len(self.step.rv))
                             script_begin += '\n' + plugin.get_input(
                                 self.params,
-                                self.step.libpath if self.step.libpath else [])
+                                self.step.libpath if self.step.libpath else [],
+                                self.step.seed)
                             if len(self.step.rf):
                                 script_begin += '\n' + plugin.get_output(
                                     self.step.rf)
